Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(4215)

Unified Diff: chrome/installer/setup/install.cc

Issue 43064: Revert the change in installer.cc to use MoveFile instead of CopyFile.... (Closed) Base URL: svn://chrome-svn.corp.google.com/chrome/branches/169/src/
Patch Set: Created 11 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/installer/setup/install.cc
===================================================================
--- chrome/installer/setup/install.cc (revision 11412)
+++ chrome/installer/setup/install.cc (working copy)
@@ -108,7 +108,8 @@
install_list->AddCopyTreeWorkItem(exe_path, exe_dst, temp_path,
WorkItem::ALWAYS);
- install_list->AddMoveTreeWorkItem(archive_path, archive_dst, temp_path);
+ install_list->AddCopyTreeWorkItem(archive_path, archive_dst, temp_path,
+ WorkItem::ALWAYS);
}
@@ -148,11 +149,11 @@
install_list->AddCreateDirWorkItem(temp_dir);
install_list->AddCreateDirWorkItem(install_path);
- // Move the version folder
- install_list->AddMoveTreeWorkItem(
+ // Copy the version folder
+ install_list->AddCopyTreeWorkItem(
AppendPath(src_path, new_version.GetString()),
AppendPath(install_path, new_version.GetString()),
- temp_dir);
+ temp_dir, WorkItem::ALWAYS); // Always overwrite.
// Delete any new_chrome.exe if present (we will end up create a new one
// if required) and then copy chrome.exe
@@ -175,10 +176,10 @@
// Extra executable for 64 bit systems.
if (Is64bit()) {
- install_list->AddMoveTreeWorkItem(
+ install_list->AddCopyTreeWorkItem(
AppendPath(src_path, installer::kWowHelperExe),
AppendPath(install_path, installer::kWowHelperExe),
- temp_dir);
+ temp_dir, WorkItem::ALWAYS);
}
// Copy the default Dictionaries only if the folder doesnt exist already
« no previous file with comments | « no previous file | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698